----------------------------------------------------------------------------------------------------------------------------------------------
----------------------------------------------------------------------------------------------------------------------------------------------

--  File:    MapOptions.lua
--  Description:   Custom MapOptions file that makes possible to set up variable options before game starts, like ModOptions.lua
--  Author:  SirArtturi, Lurker, Smoth


----------------------------------------------------------------------------------------------------------------------------------------------
----------------------------------------------------------------------------------------------------------------------------------------------

--[[  OPTION DEFINITION FILES

  CustomMapOptions.lua
  - belongs in the map archive
  - options that get used by LuaGaia

  CustomModOptions.lua
  - belongs in the mod archive
  - options that get used by LuaRules

--]]

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------

--  NOTES:
--  - using an enumerated table lets you specify the options order

--
--  These keywords must be lowercase for LuaParser to read them.
--
--  key:      the string used in the script.txt
--  name:     the displayed name
--  desc:     the description (could be used as a tooltip)
--  type:     the option type
--  def:      the default value
--  min:      minimum value for number options
--  max:      maximum value for number options
--  step:     quantization step, aligned to the def value
--  maxlen:   the maximum string length for string options
--  items:    array of item strings for list options
--  scope:    'all', 'player', 'team', 'allyteam'      <<< not supported yet >>>
--

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------

local options = {
	{
		key = 'Terrain',
		name = 'Changes terrain',
		desc = 'alter the world you play in',
		type = 'section',
	},
{
	key = 'Gameplay',
	name = 'Gameplay Options',
	desc = 'Control the gameplay options',
	type = 'section',
  },

		
	{
		key = 'inv',
		name = 'Inverts the world',
		desc = "flips things",
		type = 'bool',
		section = 'Terrain',
		def = false,
	},

  {
    key    = 'wind',
    name   = 'Wind Speed',
    desc   = 'How strong wind will blow',
	section = 'Gameplay',
    type   = 'list',
    def    = '0',
    items  = {
			{ key = '0', name = "Low", desc = "no wind speed" },
			{ key = '1', name = "Normal", desc = "Default wind speed" },
			{ key = '2', name = "High", desc = "High wind speed" },
		 },
  },
    {
    key    = 'tidal',
    name   = 'Tidal Strenght',
    desc   = 'Tidal energy levels - How much energy is produced via tidal generators',
	section = 'gameplay',
    type   = 'list',
    def    = '2',
    items  = {
      { key = '0', name = "low", desc = "no tidal movements" },
      { key = '1', name = "normal", desc = "default tidal movements" },
      { key = '2', name = "high", desc = "high tidal movements" },
		 },
  },
  
	{
		key = 'Atmosphere',
		name = 'Atmosphere settings',
		desc = 'Weather and time',
		type = 'section',
	},
	  {
    key    = 'hardness',
    name   = 'Map Hardness',
    desc   = 'Adjust the terrain hardness',
	section = 'gameplay',
    type   = 'number',
    def    = 70,
    min    = 10,
    max    = 10000,
   	 step   = 10,  -- quantization is aligned to the def value
                    -- (step <= 0) means that there is no quantization
  },
    	
	{
		key="alt",
		name="Time of day",
		desc="Night or day?",
		type="list",
		def="0",
		section= 'Atmosphere',
		items = {
			{ key = "0", name = "Day", desc = "Day Time"  },
			{ key = "1", name = "Night", desc = "Night Time" }
		},
	},
	
	{
		key="wc",
		name="Weather conditions",
		desc="Look outside",
		type="list",
		def="0",
		section= 'Atmosphere',
		items = {
			{ key = "0", name = "None", desc = "no weather"  },
			{ key = "1", name = "Snowing", desc = "snowy day" }
		},
	},
	
--	{
--	key    = 'extractorradius',
--	name   = 'Extractor Radius',
--	desc   = 'Sets the metal extractor radius',
-- 	type   = 'number',
--	def    = 100,
--	min    = 1,
--	max    = 10000,
--	section= 'Atmosphere',
--	step   = 1,  -- quantization is aligned to the def value
			-- (step <= 0) means that there is no quantization
--	},
}

return options
